#!/usr/bin/env python

from plasTeX import Environment

class textblock(Environment):
    args = 'hsize ( pos )'